==> s390-tools_2.3.0.orig.tar.gz: s390-tools-2.3.0/AUTHORS.md <==
List of all individuals having contributed content to s390-tools
----------------------------------------------------------------

- Alexey Ishchuk
- Andreas Herrmann
- Andre Wild
- Antoinette Kaschner
- Arnd Bergmann
- Axel Wirbser
- Benjamin Block
- Carsten Otte
- Christian Borntraeger
- Christian Ehrhardt
- Christof Schmitt
- Claudio Imbrenda
- Clemens von Mann
- cvs2git
- Dan Horak
- Despina Papadopoulou
- Eberhard Pasch
- Einar Lueck
- Erwin Vicari
- Eugene Crosser
- Eugene Dvurechenski
- Eugene (jno) Dvurechenski
- Farhan Ali
- Fedor Loshakov
- Felix Beck
- Frank Blaschka
- Frank Munzert
- Frank Pavlic
- Fritz Elfert
- Gerald Schaefer
- Gerhard Tonn
- Hannes Reinecke
- Hans-Joachim Picht
- Hans Wippel
- Harald Freudenberger
- Heiko Carstens
- Hendrik Brueckner
- Holger Dengler
- Holger Smolinski
- Hongjie Yang
- Horst Hummel
- Ingo Franzki
- Ingo Tuchscherer
- Jan Glauber
- Jan Hoeppner
- Jan Willeke
- Jean-Baptiste Joret
- Jens Remus
- Jochen Roehrig
- Julian Wiedmann
- Karsten Graul
- Kittipon Meesompop
- Klaus-Dieter Wacker
- Lakhvich Dmitriy
- Mark Dettinger
- Martin Kammerer
- Martin Peschke
- Martin Petermann
- Martin Schwidefsky
- Maxim Shchetynin
- Melissa Howland
- Michael
- Michael Ernst
- Michael Holzheu
- Michael Mueller
- Mijo Safradin
- Mikhail Zaslonko
- Peter Oberparleiter
- Peter Tiedemann
- Philipp Kern
- Philipp Rudo
- Rafael Fonseca
- Raimund Schroeder
- Ralph Wuerthner
- Rene Trumpp
- Rolf Schaefer
- root
- Sa Liu
- Sascha Silbe
- Sebastian Ott
- Seshagiri N Ippili
- Seshagiri N. Ippili
- Simon Sturm
- Stefan Bader
- Stefan Haberland
- Stefan Raspl
- Stefan Reimbold
- Stefan Weinhuber
- Steffen Maier
- Steffen Thoss
- Susanne Wintenberger
- Sven Schuetz
- Swen Schillig
- Taraka R. Bodireddy
- Thomas Heidrich
- Thomas Richter
- Thomas Spatzier
- Thomas Weber
- Ursula Braun
- Utz Bacher
- Viktor Mihajlovski
- Volker Sameske
- Wolfgang Taphorn

==> s390-tools-2.9.0.tar.gz: s390-tools-2.9.0/AUTHORS.md <==
List of all individuals having contributed content to s390-tools
----------------------------------------------------------------

- Alexey Ishchuk
- Andreas Herrmann
- Andre Wild
- Antoinette Kaschner
- Arnd Bergmann
- Axel Wirbser
- Benjamin Block
- Carsten Otte
- Christian Borntraeger
- Christian Ehrhardt
- Christof Schmitt
- Claudio Imbrenda
- Clemens von Mann
- Dan Horak
- Despina Papadopoulou
- Dimitri John Ledkov
- Eberhard Pasch
- Einar Lueck
- Eric Sandeen
- Erwin Vicari
- Eugene Crosser
- Eugene Dvurechenski
- Farhan Ali
- Fedor Loshakov
- Felix Beck
- Frank Blaschka
- Frank Munzert
- Frank Pavlic
- Fritz Elfert
- Gerald Schaefer
- Gerhard Tonn
- Hannes Reinecke
- Hans-Joachim Picht
- Hans Wippel
- Harald Freudenberger
- Heiko Carstens
- Hendrik Brueckner
- Holger Dengler
- Holger Smolinski
- Hongjie Yang
- Horst Hummel
- Ingo Franzki
- Ingo Tuchscherer
- Jan Glauber
- Jan Hoeppner
- Jan Willeke
- Javier Martinez Canillas
- Jean-Baptiste Joret
- Jens Remus
- Jochen Roehrig
- Julian Wiedmann
- Karsten Graul
- Kittipon Meesompop
- Klaus-Dieter Wacker
- Lakhvich Dmitriy
- Mark Dettinger
- Martin Kammerer
- Martin Peschke
- Martin Petermann
- Martin Schwidefsky
- Maxim Shchetynin
- Melissa Howland
- Michael Ernst
- Michael Holzheu
- Michael Mueller
- Mijo Safradin
- Mikhail Zaslonko
- Peter Oberparleiter
- Peter Tiedemann
- Philipp Kern
- Philipp Rudo
- Rafael Fonseca
- Raimund Schroeder
- Ralph Wuerthner
- Rene Trumpp
- Rolf Schaefer
- Sa Liu
- Sascha Silbe
- Sebastian Ott
- Seshagiri N. Ippili
- Simon Sturm
- Stefan Bader
- Stefan Haberland
- Stefan Raspl
- Stefan Reimbold
- Stefan Weinhuber
- Steffen Maier
- Steffen Thoss
- Susanne Wintenberger
- Sven Schuetz
- Swen Schillig
- Taraka R. Bodireddy
- Thomas Heidrich
- Thomas Richter
- Thomas Spatzier
- Thomas Weber
- Ursula Braun
- Utz Bacher
- Vasily Gorbik
- Viktor Mihajlovski
- Volker Sameske
- Wolfgang Taphorn
